@@ -34,9 +34,6 @@ describe 'cinder::api' do
         is_expected.to contain_cinder_config('DEFAULT/nova_catalog_info').with(
          :value => 'compute:Compute Service:publicURL'
         )
-        is_expected.to contain_cinder_config('DEFAULT/nova_catalog_admin_info').with(
-         :value => 'compute:Compute Service:adminURL'
-        )
         is_expected.to contain_cinder_config('DEFAULT/default_volume_type').with(
          :value => '<SERVICE DEFAULT>'
         )
@@ -63,19 +60,19 @@ describe 'cinder::api' do
         is_expected.to contain_cinder_config('key_manager/backend').with_value('cinder.keymgr.conf_key_mgr.ConfKeyManager')
         is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/osapi_volume_listen_port').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__middleware('cinder_config').with(
+          :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+        )
       end
     end
 
     describe 'with a custom nova_catalog params' do
       let :params do
         req_params.merge({
-          'nova_catalog_admin_info' => 'compute:nova:adminURL',
           'nova_catalog_info'       => 'compute:nova:publicURL',
         })
       end
-      it { is_expected.to contain_cinder_config('DEFAULT/nova_catalog_admin_info').with_value('compute:nova:adminURL') }
       it { is_expected.to contain_cinder_config('DEFAULT/nova_catalog_info').with_value('compute:nova:publicURL') }
     end
 
