@@ -3,7 +3,7 @@ describe 'cinder' do
   let :req_params do
     {
       :rabbit_password     => 'guest',
-      :database_connection => 'mysql://user:password@host/database',
+      :database_connection => 'mysql+pymysql://user:password@host/database',
       :lock_path           => '/var/lock/cinder',
     }
   end
@@ -47,13 +47,16 @@ describe 'cinder' do
       is_expected.to contain_cinder_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('oslo_messaging_rabbit/rabbit_userid').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('oslo_messaging_rabbit/kombu_reconnect_delay').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_cinder_config('oslo_messaging_rabbit/kombu_failover_strategy').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('oslo_messaging_rabbit/kombu_compression').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('DEFAULT/storage_availability_zone').with(:value => 'nova')
       is_expected.to contain_cinder_config('DEFAULT/default_availability_zone').with(:value => 'nova')
       is_expected.to contain_cinder_config('DEFAULT/allow_availability_zone_fallback').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('DEFAULT/api_paste_config').with(:value => '/etc/cinder/api-paste.ini')
-      is_expected.to contain_cinder_config('DEFAULT/backend_host').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('oslo_concurrency/lock_path').with(:value => '/var/lock/cinder')
+
+      # backend_host should not be written to DEFAULT section
+      is_expected.to_not contain_cinder_config('DEFAULT/backend_host')
     end
 
   end
@@ -287,14 +290,4 @@ describe 'cinder' do
     it { is_expected.to contain_cinder_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673') }
   end
 
-  describe 'with backend_host' do
-    let :params do
-      req_params.merge({
-        :backend_host => 'cinder_backend',
-      })
-    end
-
-    it { is_expected.to contain_cinder_config('DEFAULT/backend_host').with_value('cinder_backend') }
-  end
-
 end
